@@ -641,6 +641,12 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.actionNew,
 			QtCore.SIGNAL("activated()"),
 			self.set_defaults)
+		self.connect(self.ui.instrumentcombo,
+			QtCore.SIGNAL("activated(int)"),
+			lambda x: self.add_instrument())
+		self.connect(self.ui.progressioncombo, 
+			QtCore.SIGNAL("activated(int)"),
+			lambda x: self.add_progression())
 	
 
 	def set_defaults(self):
@@ -684,6 +690,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 	def add_progression(self):
 		self.ui.progressions.addItem(
 			self.ui.progressioncombo.currentText())
+		self.ui.progressions.setCurrentRow(int(self.ui.progressions.count()) - 1)
+		self.edit_progression()
 
 	def remove_progression(self):
 		i = self.ui.progressions.currentRow()
@@ -891,7 +899,7 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 
 		# Checkboxes
 		o.swing = int(self.ui.swing.isChecked())
-		o.no_fluidsynth = self.no_fluidsynth
+		o.no_fluidsynth = int(self.no_fluidsynth)
 
 		o.instrument = self.get_instruments()
 		o.progression = self.get_progressions()
